
# pacotes -----------------------------------------------------------------

# instalando pacote
install.packages("janitor")

# carregando pacotes
library(readxl)
library(writexl)
library(readODS)
library(janitor)
library(tidyverse)


help("library")

sqrt("Gilberto")


# operações básicas -------------------------------------------------------

# soma
1 + 1
# subtração
3 - 1
# multiplicação
2 * 7
# divisão
1 / 2
# potenciação
2^3
# parte inteira da divisão
5 %/% 3
# resto da divisão
5 %% 3


# tipo de dados -----------------------------------------------------------

# texto -- character
class("Gilberto")
# número real
class(1)
# número inteiro
class(1L)
# número complexo
class(1 + 2i)
# valor lógico
class(TRUE)
class(FALSE)


# Estrtura de dados homogêneos --------------------------------------------

# vector numérico
idaDe <- c(23, 22, 21)
idade <- c(23, 22, 21)
class(idade)
class(22)

# vetor de texto
nome <- c("Carolina", "Gilberto", "Rodrigo")
nome[3] <- "Ramon"
nome

# vetores vazio
primeiro_nome <- vector("character", 3)
idade <- vector("double", 3)


# matrizes ----------------------------------------------------------------

# matriz de texto
valores <- c("Kerole", "Carolina", "Rodrigo", "Gilberto")
matriz_nomes <- matrix(valores, nrow = 2, ncol = 2, byrow = TRUE)
matriz_nomes
# primeira coluna
primeira_coluna <- matriz_nomes[, 1]
primeira_coluna
# apenas um elemento da matriz
nome <- matriz_nomes[1, 1]
nome

valores <- c("Kerole", "Carolina", "Rodrigo", "Gilberto")
matriz_nomes <- matrix(valores, nrow = 2, ncol = 3)
matriz_nomes

matriz_zeros <- matrix(0,  4, 5)
matriz_zeros

sequencia <- seq(from = 16, to = 1, by = -1)
sequencia
matriz_por_linhas <- matrix(sequencia, 4, byrow = TRUE)
matriz_por_linhas

sequencia <- 1:16 # seq(from = 1, to = 16, by = 1)

submatriz <- matriz_por_linhas[c(1,4), c(1, 3)]
submatriz
matriz_por_linhas[3, 3]

colunas <- matriz_por_linhas[, c(3, 4)]
colunas

linhas <- matriz_por_linhas[c(3, 4), ]
linhas


mistura <- c(22, "21")
mistura

nova_mistura <- c(TRUE, 1L, 22)
nova_mistura


# array -------------------------------------------------------------------


dados_matriz_1 <- 10:13
dados_matriz_2  <- 14:17
resultado <- array(c(dados_matriz_1, dados_matriz_2), dim = c(2, 2, 2))
resultado

primeira_matriz <- resultado[,, 1]
primeira_matriz

# operações com vetores
vetor_a <- c(1, 3, 10)
vetor_b <- c(1, 2, 3, 4)
vetor_a + vetor_b
vetor_a - vetor_b
vetor_a * vetor_b
vetor_a / vetor_b

# valores especiais -------------------------------------------------------


# valor faltante
idade <- c(23, 22, 21, NA)
idade
sum(idade)

resultado <- c(2, 3, NaN)
sum(resultado)

resultado <- c(0, 1, -Inf)
sum(resultado)


# estrura de dados heterogênea --------------------------------------------

lista <- list("Gilberto", idade = 36, genero = "M", 
              info_prof = list(data_ingresso = 2017, cargo = "professor"),
              turmas = c(4, 5))
lista[[1]]
lista[[2]]
lista$idade

lista[c(1, 2, 3, 5)]


idade <- c(23, 22, 21)
nomes <- c("Gilberto", "Carolina", "Rodrigo")

df_equipe <- tibble(nome = nomes, idade = idade)

nome_recuperado <- df_equipe$nome
class(nome_recuperado)

glimpse(df_equipe)
head(df_equipe, n = 2)
tail(df_equipe, n = 2)
class(df_equipe)


# lendo dados -------------------------------------------------------------

# arquivos excel

# windows
# df_iris <- read_xlsx("dados\\bruto\\dados_iris.xlsx")

df_iris <- read_xlsx("dados/bruto/dados_iris.xlsx")
glimpse(df_iris)
head(df_iris, n = 4)
tail(df_iris, n = 4)

tab <- rename(adorn_pct_formatting(adorn_totals(tabyl(df_iris, especies)), digits = 2), "Espécies" = especies, "Frequência absoluta" = n, "Porcentagem" = percent)


tab <- df_iris |>
  tabyl(especies) |>
  adorn_totals() |>
  adorn_pct_formatting(digits = 2) |> 
  rename("Espécies" = especies, "Frequência absoluta" = n, "Porcentagem" = percent)

write_xlsx(tab, "output/tabela_iris.xlsx")

df_enem <- read_csv2("dados/bruto/enem_salvador_2021.csv")
glimpse(df_enem)

faixas <- seq(from = 0, to = 1000, by = 100)
dados_enem <- df_enem |>
  mutate(faixa_nota_mt = cut(NU_NOTA_MT, breaks = faixas, include.lowest = TRUE, right = FALSE))
glimpse(dados_enem)

tab_nota <- dados_enem |>
  tabyl(faixa_nota_mt) |>
  adorn_totals() |>
  adorn_pct_formatting(digits = 3) |>
  rename("Nota em Matemática" = faixa_nota_mt, "Frequência" = n, "Porcentagem" = percent)
tab_nota

write_xlsx(tab_nota, "output/notas_matematica_enem.xlsx")
